Documentation
¶
Index ¶
- func MarshalPrivateKey(key *PrivateKey) ([]byte, error)
- func MarshalPublicKey(pub *PublicKey) ([]byte, error)
- func ToPrivateKey(key *PrivateKey) (*crypto_ecdh.PrivateKey, error)
- func ToPublicKey(pub *PublicKey) (*crypto_ecdh.PublicKey, error)
- type Curve
- type ECMQVCurve
- type PrivateKey
- func (k *PrivateKey) Bytes() []byte
- func (k *PrivateKey) Curve() Curve
- func (k *PrivateKey) ECDH(remote *PublicKey) ([]byte, error)
- func (k *PrivateKey) ECMQV(eLocal *PrivateKey, sRemote, eRemote *PublicKey) (*PublicKey, error)
- func (k *PrivateKey) Equal(x crypto.PrivateKey) bool
- func (k *PrivateKey) Public() crypto.PublicKey
- func (k *PrivateKey) PublicKey() *PublicKey
- type PublicKey
- func (k *PublicKey) Bytes() []byte
- func (k *PublicKey) Curve() Curve
- func (k *PublicKey) Equal(x crypto.PublicKey) bool
- func (k *PublicKey) SM2SharedKey(sPub, sRemote *PublicKey, uid, remoteUID []byte, kenLen int) ([]byte, error)
- func (k *PublicKey) SM2ZA(h func() hash.Hash, uid []byte) ([]byte, error)
- type SM2ZACurve
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ToPrivateKey ¶
func ToPrivateKey(key *PrivateKey) (*crypto_ecdh.PrivateKey, error)
func ToPublicKey ¶
func ToPublicKey(pub *PublicKey) (*crypto_ecdh.PublicKey, error)
Types ¶
type Curve ¶
type Curve interface {
// GenerateKey generates a random PrivateKey.
//
// Most applications should use [crypto/rand.Reader] as rand. Note that the
// returned key does not depend deterministically on the bytes read from rand,
// and may change between calls and/or between versions.
GenerateKey(rand io.Reader) (*PrivateKey, error)
// NewPrivateKey checks that key is valid and returns a PrivateKey.
//
// For NIST curves, this follows SEC 1, Version 2.0, Section 2.3.6, which
// amounts to decoding the bytes as a fixed length big endian integer and
// checking that the result is lower than the order of the curve. The zero
// private key is also rejected, as the encoding of the corresponding public
// key would be irregular.
//
// For X25519, this only checks the scalar length.
NewPrivateKey(key []byte) (*PrivateKey, error)
// NewPublicKey checks that key is valid and returns a PublicKey.
//
// For NIST curves, this decodes an uncompressed point according to SEC 1,
// Version 2.0, Section 2.3.4. Compressed encodings and the point at
// infinity are rejected.
//
// For X25519, this only checks the u-coordinate length. Adversarially
// selected public keys can cause ECDH to return an error.
NewPublicKey(key []byte) (*PublicKey, error)
// ecdh performs a ECDH exchange and returns the shared secret. It's exposed
// as the PrivateKey.ECDH method.
//
// The private method also allow us to expand the ECDH interface with more
// methods in the future without breaking backwards compatibility.
ECDH(local *PrivateKey, remote *PublicKey) ([]byte, error)
// PrivateKeyToPublicKey converts a PrivateKey to a PublicKey. It's exposed
// as the PrivateKey.PublicKey method.
//
// This method always succeeds: for X25519, the zero key can't be
// constructed due to clamping; for NIST curves, it is rejected by
// NewPrivateKey.
PrivateKeyToPublicKey(*PrivateKey) *PublicKey
}
func GmSM2 ¶
func GmSM2() Curve
Multiple invocations of this function will return the same value, so it can be used for equality checks and switch statements.
func NewNistCurve ¶
type ECMQVCurve ¶
type ECMQVCurve interface {
ECMQV(sLocal, eLocal *PrivateKey, sRemote, eRemote *PublicKey) (*PublicKey, error)
}
ECMQVCurve
type PrivateKey ¶
type PrivateKey struct {
NamedCurve Curve
KeyBytes []byte
// contains filtered or unexported fields
}
PrivateKey is an ECDH private key, usually kept secret.
These keys can be parsed with crypto/x509.ParsePKCS8PrivateKey and encoded with crypto/x509.MarshalPKCS8PrivateKey. For NIST curves, they then need to be converted with crypto/ecdsa.PrivateKey.ECDH after parsing.
func FromPrivateKey ¶
func FromPrivateKey(key *crypto_ecdh.PrivateKey) (*PrivateKey, error)
func SM2PrivateKeyToECDH ¶
func SM2PrivateKeyToECDH(pri *sm2.PrivateKey) (*PrivateKey, error)
私钥导入为 ECDH 私钥
func (*PrivateKey) Bytes ¶
func (k *PrivateKey) Bytes() []byte
Bytes returns a copy of the encoding of the private key.
func (*PrivateKey) Curve ¶
func (k *PrivateKey) Curve() Curve
func (*PrivateKey) ECDH ¶
func (k *PrivateKey) ECDH(remote *PublicKey) ([]byte, error)
ECDH performs a ECDH exchange and returns the shared secret. The PrivateKey and PublicKey must use the same curve.
For NIST curves, this performs ECDH as specified in SEC 1, Version 2.0, Section 3.3.1, and returns the x-coordinate encoded according to SEC 1, Version 2.0, Section 2.3.5. The result is never the point at infinity.
For X25519, this performs ECDH as specified in RFC 7748, Section 6.1. If the result is the all-zero value, ECDH returns an error.
func (*PrivateKey) ECMQV ¶
func (k *PrivateKey) ECMQV(eLocal *PrivateKey, sRemote, eRemote *PublicKey) (*PublicKey, error)
ECMQV performs a ECMQV exchange and return the shared secret.
func (*PrivateKey) Equal ¶
func (k *PrivateKey) Equal(x crypto.PrivateKey) bool
Equal returns whether x represents the same private key as k.
Note that there can be equivalent private keys with different encodings which would return false from this check but behave the same way as inputs to ECDH.
This check is performed in constant time as long as the key types and their curve match.
func (*PrivateKey) Public ¶
func (k *PrivateKey) Public() crypto.PublicKey
Public implements the implicit interface of all standard library private keys. See the docs of crypto.PrivateKey.
func (*PrivateKey) PublicKey ¶
func (k *PrivateKey) PublicKey() *PublicKey
type PublicKey ¶
PublicKey is an ECDH public key, usually a peer's ECDH share sent over the wire.
These keys can be parsed with crypto/x509.ParsePKIXPublicKey and encoded with crypto/x509.MarshalPKIXPublicKey. For NIST curves, they then need to be converted with crypto/ecdsa.PublicKey.ECDH after parsing.
func FromPublicKey ¶
func FromPublicKey(pub *crypto_ecdh.PublicKey) (*PublicKey, error)
func SM2PublicKeyToECDH ¶
公钥导入为 ECDH 公钥
func (*PublicKey) Equal ¶
Equal returns whether x represents the same public key as k.
Note that there can be equivalent public keys with different encodings which would return false from this check but behave the same way as inputs to ECDH.
This check is performed in constant time as long as the key types and their curve match.